﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

using com.citizen.sdk.LabelPrint;

namespace LabelApplication{
    public partial class Form1 : Form{

        private LabelPrinter printer;

        public Form1(){

            InitializeComponent();

            // ComboBoxColumnで使用するDataTableの作成
            DataTable dataTable1 = new DataTable("ComboBox");
            dataTable1.Columns.Add("Display", typeof(string));
            dataTable1.Columns.Add("Value", typeof(int));
            dataTable1.Rows.Add("NET", LabelConst.CLS_PORT_NET);
            dataTable1.Rows.Add("USB", LabelConst.CLS_PORT_USB);
            dataTable1.Rows.Add("COM", LabelConst.CLS_PORT_COM);
            dataTable1.Rows.Add("LPT", LabelConst.CLS_PORT_LPT);
            dataTable1.Rows.Add("Bluetooth", LabelConst.CLS_PORT_Bluetooth);
            ifCmbBox.DataSource = dataTable1;
            ifCmbBox.DisplayMember = "Display";
            ifCmbBox.ValueMember = "Value";
            ifCmbBox.SelectedIndex = 0;
            
        }

        private void Form1_Load(object sender, EventArgs e){

            listView1.Items.Clear();
            listView1.Columns.Add("Port", 120, HorizontalAlignment.Left);
            listView1.Columns.Add("", 210, HorizontalAlignment.Left);

            statusBox.Text = "";
            connectLabel.Text = "";
            disconnectLabel.Text = "";

        }

        /**
         * "Search Printer" button pressed
         */
        private void searchBtn_Click(object sender, EventArgs e)
        {
            int searchmode = 0;     // searchmode == 0  : SearchCitizenPrinter
                                    //            != 0  : SearchLabelPrinter
            int res = 0;
            int type = 0;

            //Initialize
            connectLabel.Text = "";
            disconnectLabel.Text = "";
            listView1.Items.Clear();
            type = (int)ifCmbBox.SelectedValue;

            if (searchmode == 0)
            {
                // 
                // example for SearchCitizenPrinter
                //

                printer = new LabelPrinter();
                CitizenPrinterInfo[] info;

                //Search available Citizen printers
                info = printer.SearchCitizenPrinter(type, 10, out res);
                if (res != LabelConst.CLS_SUCCESS)
                {
                    if (res == LabelConst.CLS_E_NO_LIST)
                    {
                        MessageBox.Show("Printer Not Found.");
                    }
                    else
                    {
                        MessageBox.Show("SearchCitizenPrinter Failed");
                    }
                    return;
                }

                //List up all available Citizen printers in the listView
                for (int i = 0; i < info.Length; i++)
                {
                    string[] CLSs = new string[2];
                    switch (type)
                    {

                        case LabelConst.CLS_PORT_NET:
                            CLSs[0] = info[i].ipAddress;
                            CLSs[1] = info[i].macAddress;
                            break;

                        case LabelConst.CLS_PORT_USB:
                            CLSs[0] = info[i].deviceName;
                            CLSs[1] = info[i].printerModel;
                            break;

                        case LabelConst.CLS_PORT_COM:
                            CLSs[0] = info[i].deviceName;
                            break;

                        case LabelConst.CLS_PORT_LPT:
                            CLSs[0] = info[i].deviceName;
                            break;

                        case LabelConst.CLS_PORT_Bluetooth:
                            CLSs[0] = info[i].bdAddress;
                            CLSs[1] = info[i].deviceName;
                            break;

                    }
                    listView1.Items.Add(new ListViewItem(CLSs));
                }
            }
            else
            {
                // 
                // example for SearchLabelPrinter
                //

                printer = new LabelPrinter();
                string[] address;

                //Search available Label printers
                address = printer.SearchLabelPrinter(type, 10, out res);
                if (res != LabelConst.CLS_SUCCESS)
                {
                    if (res == LabelConst.CLS_E_NO_LIST)
                    {
                        MessageBox.Show("Printer Not Found.");
                    }
                    else
                    {
                        MessageBox.Show("SearchLabelPrinter Failed");
                    }
                    return;
                }

                //List up all available Label printers in the listView
                for (int i = 0; i < address.Length; i++)
                {
                    string CLSs = address[i];
                    listView1.Items.Add(new ListViewItem(CLSs));
                }
            }

            listView1.Focus();
            listView1.Items[0].Selected = true;

        }

        private void ifCmbBox_SelectedIndexChanged(object sender, EventArgs e)
        {
            listView1.Items.Clear();
        }

        /**
         * "Connect" button pressed
         */
        private void connectBtn_Click(object sender, EventArgs e){

            connectLabel.Text = "";
            disconnectLabel.Text = "";

            //Check if a printer is selected
            if (listView1.SelectedItems.Count <= 0)
            {
                MessageBox.Show("No printer is selected.");
                return;
            }

            // Get I/F type
            int type = (int)ifCmbBox.SelectedValue;

            // Create an instance (LabelPrinter Class)
            printer = new LabelPrinter();

            // Connect
            int res = printer.Connect(type, listView1.SelectedItems[0].Text);
            connectLabel.Text = res.ToString();

        }

        /**
         * "Disconnect" button pressed
         */
        private void disconnectBtn_Click(object sender, EventArgs e){

            //Check if the printer has been connected.
            if (printer == null) {
                MessageBox.Show("Printer is not connected.");
                return;
            }

            // Disconnect
            int res = printer.Disconnect();
            disconnectLabel.Text = res.ToString();

            printer = null;

            if (timer1.Enabled) {
                timer1.Enabled = false;
            }
        }

        /**
         * "Start Checking Status" button pressed
         */
        private void checkStatusBtn_Click(object sender, EventArgs e){
            
            //Check if the printer has been connected.
            if (printer == null){
                MessageBox.Show("Printer is not connected.");
                return;
            }

            timer1.Interval = 3000;
            timer1.Enabled = true;

        }

        private void timer1_Tick(object sender, EventArgs e)
        {
            //Checks the status and populates into each property
            printer.PrinterCheck();

            statusBox.Text = "";

            statusBox.Text = statusBox.Text + printer.GetCommandInterpreterInAction().ToString() + ":\tCommand interpreter in action" + "\r\n";
            statusBox.Text = statusBox.Text + printer.GetPaperError().ToString() + ":\tPaper error" + "\r\n";
            statusBox.Text = statusBox.Text + printer.GetRibbonEnd().ToString() + ":\tRibbon end" + "\r\n";
            statusBox.Text = statusBox.Text + printer.GetBatchProcessing().ToString() + ":\tBatch processing" + "\r\n";
            statusBox.Text = statusBox.Text + printer.GetPrinting().ToString() + ":\tPrinting" + "\r\n";
            statusBox.Text = statusBox.Text + printer.GetPause().ToString() + ":\tPause" + "\r\n";
            statusBox.Text = statusBox.Text + printer.GetWaitingForPeeling().ToString() + ":\tWaiting for peeling" + "\r\n";

        }

    }
}
