﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;

using com.citizen.sdk.LabelPrint;

namespace LabelApplication
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();

            // ComboBoxColumnで使用するDataTableの作成
            DataTable dataTable1 = new DataTable("ComboBox");
            dataTable1.Columns.Add("Display", typeof(string));
            dataTable1.Columns.Add("Value", typeof(int));
            dataTable1.Rows.Add("NET", LabelConst.CLS_PORT_NET);
            dataTable1.Rows.Add("USB", LabelConst.CLS_PORT_USB);
            dataTable1.Rows.Add("COM", LabelConst.CLS_PORT_COM);
            dataTable1.Rows.Add("LPT", LabelConst.CLS_PORT_LPT);
            dataTable1.Rows.Add("Bluetooth", LabelConst.CLS_PORT_Bluetooth);
            ifCmbBox.DataSource = dataTable1;
            ifCmbBox.DisplayMember = "Display";
            ifCmbBox.ValueMember = "Value";
            ifCmbBox.SelectedIndex = 0;

        }

        private void Form1_Load(object sender, EventArgs e)
        {

            listView1.Items.Clear();
            listView1.Columns.Add("Port", 120, HorizontalAlignment.Left);
            listView1.Columns.Add("", 210, HorizontalAlignment.Left);

        }

        /**
         * "Search Printer" button pressed
         */
        private void searchbtn_Click(object sender, EventArgs e)
        {

            int searchmode = 0;     // searchmode == 0  : SearchCitizenPrinter
            //            != 0  : SearchLabelPrinter
            int res = 0;
            int type = 0;
            LabelPrinter printer = new LabelPrinter();

            //Initialize
            listView1.Items.Clear();
            type = (int)ifCmbBox.SelectedValue;

            if (searchmode == 0)
            {
                // 
                // example for SearchCitizenPrinter
                //

                CitizenPrinterInfo[] info;

                //Search available Citizen printers
                info = printer.SearchCitizenPrinter(type, 10, out res);
                if (res != LabelConst.CLS_SUCCESS)
                {
                    if (res == LabelConst.CLS_E_NO_LIST)
                    {
                        MessageBox.Show("Printer Not Found.");
                    }
                    else
                    {
                        MessageBox.Show("SearchCitizenPrinter Failed");
                    }
                    return;
                }

                //List up all available Citizen printers in the listView
                for (int i = 0; i < info.Length; i++)
                {
                    string[] CLSs = new string[2];
                    switch (type)
                    {

                        case LabelConst.CLS_PORT_NET:
                            CLSs[0] = info[i].ipAddress;
                            CLSs[1] = info[i].macAddress;
                            break;

                        case LabelConst.CLS_PORT_USB:
                            CLSs[0] = info[i].deviceName;
                            CLSs[1] = info[i].printerModel;
                            break;

                        case LabelConst.CLS_PORT_COM:
                            CLSs[0] = info[i].deviceName;
                            break;

                        case LabelConst.CLS_PORT_LPT:
                            CLSs[0] = info[i].deviceName;
                            break;

                        case LabelConst.CLS_PORT_Bluetooth:
                            CLSs[0] = info[i].bdAddress;
                            CLSs[1] = info[i].deviceName;
                            break;

                    }
                    listView1.Items.Add(new ListViewItem(CLSs));
                }
            }
            else
            {
                // 
                // example for SearchLabelPrinter
                //

                string[] address;

                //Search available Label printers
                address = printer.SearchLabelPrinter(type, 10, out res);
                if (res != LabelConst.CLS_SUCCESS)
                {
                    if (res == LabelConst.CLS_E_NO_LIST)
                    {
                        MessageBox.Show("Printer Not Found.");
                    }
                    else
                    {
                        MessageBox.Show("SearchLabelPrinter Failed");
                    }
                    return;
                }

                //List up all available Label printers in the listView
                for (int i = 0; i < address.Length; i++)
                {
                    string CLSs = address[i];
                    listView1.Items.Add(new ListViewItem(CLSs));
                }
            }

            listView1.Focus();
            listView1.Items[0].Selected = true;

        }

        private void ifCmbBox_SelectedIndexChanged(object sender, EventArgs e)
        {
            listView1.Items.Clear();
        }

        /**
         * "Print" button pressed
         */
        private void printbtn_Click(object sender, EventArgs e)
        {

            //Check if a printer is selected
            if (listView1.SelectedItems.Count <= 0)
            {
                MessageBox.Show("No printer is selected.");
                return;
            }

            //Get I/F type
            int type = (int)ifCmbBox.SelectedValue;

            // Create an instance (LabelDesign Class)
            LabelDesign design = new LabelDesign();

            // Design label
            this.DesignLabel(design);

            // Create an instance (LabelPrinter Class)
            LabelPrinter printer = new LabelPrinter();
            printer.SetMeasurementUnit(LabelConst.CLS_UNIT_INCH);
            printer.SetFormatAttribute(1);

            // Connect
            int ret = printer.Connect(type, listView1.SelectedItems[0].Text);
            if (ret != LabelConst.CLS_SUCCESS)
            {
                MessageBox.Show("Connect error: " + ret.ToString(), "Error");
                return;
            }

            // Print label
            printer.Print(design, 1);

            // Disconnect
            printer.Disconnect();

        }

        private void previewbtn_Click(object sender, EventArgs e)
        {
            // Create an instance (LabelDesign Class)
            LabelDesign design = new LabelDesign();

            // Design label
            this.DesignLabel(design);

            // Create an instance (LabelPrinter Class)
            LabelPrinter printer = new LabelPrinter();

            // Preview lable
            printer.Preview(design, LabelConst.CLS_PRT_RES_203, LabelConst.CLS_UNIT_INCH, 400, 600);
        }


        private void DesignLabel(LabelDesign design)
        {

            // Frame
            design.DrawRect(0, 5, 385, 570, 2);


            // Icon
            design.DrawBitmap("Resources\\_logo1.jpg", LabelConst.CLS_RT_NORMAL, 130, 70, 10, 538, LabelConst.CLS_PRT_RES_203, LabelConst.CLS_UNIT_INCH);
            // Message
            design.DrawTextPtrFont("Sample Label", LabelConst.CLS_LOCALE_JP, LabelConst.CLS_PRT_FNT_TRIUMVIRATE, LabelConst.CLS_RT_NORMAL, 1, 1, LabelConst.CLS_PRT_FNT_SIZE_8, 85, 555);
            design.DrawTextPtrFont("PRINT SERVICE", LabelConst.CLS_LOCALE_JP, LabelConst.CLS_PRT_FNT_TRIUMVIRATE, LabelConst.CLS_RT_NORMAL, 1, 1, LabelConst.CLS_PRT_FNT_SIZE_8, 85, 540);
            design.DrawTextPtrFont("ABCD EFG", LabelConst.CLS_LOCALE_JP, LabelConst.CLS_PRT_FNT_TRIUMVIRATE, LabelConst.CLS_RT_NORMAL, 1, 1, LabelConst.CLS_PRT_FNT_SIZE_14, 200, 540);
            // Line
            design.DrawLine(0, 535, 385, 535, 2);       // Horizontal


            // Icon
            design.DrawBitmap("Resources\\_logo2.jpg", LabelConst.CLS_RT_NORMAL, 150, 170, 5, 450, LabelConst.CLS_PRT_RES_203, LabelConst.CLS_UNIT_INCH);
            // Message
            design.DrawTextPtrFont("X.Y POSTAGE PAID", LabelConst.CLS_LOCALE_JP, LabelConst.CLS_PRT_FNT_TRIUMVIRATE, LabelConst.CLS_RT_NORMAL, 1, 1, LabelConst.CLS_PRT_FNT_SIZE_8, 170, 510);
            design.DrawTextPtrFont("COMMERCIAL BASE", LabelConst.CLS_LOCALE_JP, LabelConst.CLS_PRT_FNT_TRIUMVIRATE, LabelConst.CLS_RT_NORMAL, 1, 1, LabelConst.CLS_PRT_FNT_SIZE_8, 170, 490);
            design.DrawTextPtrFont("PRICING", LabelConst.CLS_LOCALE_JP, LabelConst.CLS_PRT_FNT_TRIUMVIRATE, LabelConst.CLS_RT_NORMAL, 1, 1, LabelConst.CLS_PRT_FNT_SIZE_8, 190, 470);
            // Line
            design.DrawLine(78, 450, 78, 535, 1);       // Vertical
            design.DrawLine(0, 450, 385, 450, 2);       // Horizontal


            // Message
            design.DrawTextPtrFont("ABC PRINT SERVICE", LabelConst.CLS_LOCALE_JP, LabelConst.CLS_PRT_FNT_TRIUMVIRATE_B, LabelConst.CLS_RT_NORMAL, 1, 1, LabelConst.CLS_PRT_FNT_SIZE_24, 20, 410);
            // Line
            design.DrawLine(0, 410, 385, 410, 2);       // Horizontal


            // Message
            design.DrawTextPtrFont("John Smith", LabelConst.CLS_LOCALE_JP, LabelConst.CLS_PRT_FNT_TRIUMVIRATE, LabelConst.CLS_RT_NORMAL, 1, 1, LabelConst.CLS_PRT_FNT_SIZE_8, 15, 385);
            design.DrawTextPtrFont("901 D ST SW STE 101", LabelConst.CLS_LOCALE_JP, LabelConst.CLS_PRT_FNT_TRIUMVIRATE, LabelConst.CLS_RT_NORMAL, 1, 1, LabelConst.CLS_PRT_FNT_SIZE_8, 15, 370);
            design.DrawTextPtrFont("WASHINGTON DC 2XX24-21XX", LabelConst.CLS_LOCALE_JP, LabelConst.CLS_PRT_FNT_TRIUMVIRATE, LabelConst.CLS_RT_NORMAL, 1, 1, LabelConst.CLS_PRT_FNT_SIZE_8, 15, 355);
            design.DrawTextPtrFont("Citizen Systems", LabelConst.CLS_LOCALE_JP, LabelConst.CLS_PRT_FNT_TRIUMVIRATE, LabelConst.CLS_RT_NORMAL, 1, 1, LabelConst.CLS_PRT_FNT_SIZE_8, 40, 290);
            design.DrawTextPtrFont("475 LENFANT PLZ SW", LabelConst.CLS_LOCALE_JP, LabelConst.CLS_PRT_FNT_TRIUMVIRATE, LabelConst.CLS_RT_NORMAL, 1, 1, LabelConst.CLS_PRT_FNT_SIZE_8, 40, 275);
            design.DrawTextPtrFont("WASHINGTON DC 2X26X-XXX4", LabelConst.CLS_LOCALE_JP, LabelConst.CLS_PRT_FNT_TRIUMVIRATE, LabelConst.CLS_RT_NORMAL, 1, 1, LabelConst.CLS_PRT_FNT_SIZE_8, 40, 260);
            // Line
            design.DrawLine(210, 410, 210, 240, 2);     // Vertical
            design.DrawLine(0, 240, 385, 240, 2);       // Horizontal


            // QR Code
            design.DrawQRCode("Sample QR Code", LabelConst.CLS_ENC_CDPG_SHIFT_JIS, LabelConst.CLS_RT_NORMAL, 6, LabelConst.CLS_QRCODE_EC_LEVEL_H, 260, 290);


            // Message
            design.DrawTextPtrFont("Sample Barcode", LabelConst.CLS_LOCALE_JP, LabelConst.CLS_PRT_FNT_TRIUMVIRATE, LabelConst.CLS_RT_NORMAL, 1, 1, LabelConst.CLS_PRT_FNT_SIZE_12, 130, 210);
            // Barcode
            design.DrawBarCode("123456789", LabelConst.CLS_BCS_CODE128, LabelConst.CLS_RT_NORMAL, 6, 3, 90, 100, 100, LabelConst.CLS_BCS_TEXT_HIDE);
            // Line
            design.DrawLine(0, 80, 385, 80, 2);


            // Message
            design.DrawTextPtrFont("COMMENTS:", LabelConst.CLS_LOCALE_JP, LabelConst.CLS_PRT_FNT_TRIUMVIRATE, LabelConst.CLS_RT_NORMAL, 1, 1, LabelConst.CLS_PRT_FNT_SIZE_8, 15, 65);
            design.DrawTextPtrFont("123456789", LabelConst.CLS_LOCALE_JP, LabelConst.CLS_PRT_FNT_TRIUMVIRATE, LabelConst.CLS_RT_NORMAL, 1, 1, LabelConst.CLS_PRT_FNT_SIZE_8, 40, 50);
            design.DrawTextPtrFont("abcdefghijklmnopqrstuvwxyz", LabelConst.CLS_LOCALE_JP, LabelConst.CLS_PRT_FNT_TRIUMVIRATE, LabelConst.CLS_RT_NORMAL, 1, 1, LabelConst.CLS_PRT_FNT_SIZE_8, 40, 35);
            design.DrawTextPtrFont("ABCDEFGHIJKLMNOPQRSTUVWXYZ", LabelConst.CLS_LOCALE_JP, LabelConst.CLS_PRT_FNT_TRIUMVIRATE, LabelConst.CLS_RT_NORMAL, 1, 1, LabelConst.CLS_PRT_FNT_SIZE_8, 40, 20);

        }

    }
}
